#!/bin/bash

set -eu

MYDIR=$(dirname "$(readlink -f "$0")")

function print_result_table()
{
    local benchmark_type=$1
    local nice_level=$2
    shift 2
    local types=("$@")
    local max_workers=$(( $(nproc --all) - 1 ))
    for workers in 1 "$max_workers"; do
        echo Workers: "$workers (nice $nice_level)"
        for type in "${types[@]}"; do
            echo -n "$type"
            for factor in {0..7}; do
                echo -en "\\t$(grep Raw: benchmark-"$benchmark_type"-"$type"-nice=$nice_level,workers=$workers,factor="$factor",iteration=?,worker=?.txt \
            | awk '{sum+=$2} END { print sum }')"
            done
            echo
        done | python "$MYDIR"/analyze-results.py "${types[@]}"
    done
}

echo CPU looper nice 0:
print_result_table cpulooper 0 default chrt-batch nice nice-19 nice-19-chrt-batch chrt-idle
echo Memory looper nice 0:
print_result_table memlooper 0 default chrt-batch nice nice-19 nice-19-chrt-batch chrt-idle

echo CPU looper nice 10:
print_result_table cpulooper 10 default nice-19 nice-19-chrt-batch chrt-idle
echo Memory looper nice 10:
print_result_table memlooper 10 default nice-19 nice-19-chrt-batch chrt-idle

echo CPU looper nice 19:
print_result_table cpulooper 19 default chrt-idle
echo Memory looper nice 19:
print_result_table memlooper 19 default chrt-idle
