#!/bin/bash

set -eu

BENCHMARK_TYPE=$1
WORKERS=$2
CPU_FACTOR=$3
ITERATIONS=$4
LOOP_PROCESS=$5
shift 5
BENCHMARK_PROCESS=("$@")

PROCESSES=$(( $(nproc --all) * CPU_FACTOR ))

function norun()
{
    sleep 100000
}

function run_benchmark()
{
    local type=$1
    shift
    local policy=("$@")

    local looper_pids=()
    for _ in $(seq 1 "$PROCESSES"); do
        if [ "${#policy[@]}" -gt 0 ]; then
            "${policy[@]}" "$LOOP_PROCESS" &
            looper_pids+=("$!")
        else
            "$LOOP_PROCESS" &
            looper_pids+=("$!")
        fi
    done

    echo "Benchmarking $BENCHMARK_TYPE $type CPU factor $CPU_FACTOR with $WORKERS workers"
    for iteration in $(seq 1 "$ITERATIONS"); do
        local benchmark_pids=()
        for worker in $(seq 1 "$WORKERS"); do
            "${BENCHMARK_PROCESS[@]}" > "benchmark-$BENCHMARK_TYPE-$type-workers=$WORKERS,factor=$CPU_FACTOR,iteration=$iteration,worker=$worker.txt" &
            benchmark_pids+=("$!")
        done

        wait "${benchmark_pids[@]}" || :
    done

    if [ "${#looper_pids[@]}" -gt 0 ]; then
        kill "${looper_pids[@]}"
    fi

    wait || :
}

run_benchmark default

run_benchmark chrt-batch chrt --batch 0

run_benchmark nice nice

run_benchmark nice-19 nice -n 19

run_benchmark nice-19-chrt-batch nice -n 19 chrt --batch 0

run_benchmark chrt-idle chrt --idle 0
